"""
.. include:: ../../README.md
"""

__author__ = """Bruno Manuel Santos Saraiva"""
__email__ = 'bruno.msaraiva2@gmail.com'
